"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const pptxgenjs_1 = __importDefault(require("pptxgenjs"));
const fs_1 = __importDefault(require("fs"));
class GeneratePptxGenJs {
    constructor(automizer, slides) {
        this.countSlides = 0;
        this.supportedSlideItems = (pgenSlide, generateElement, addedObjects) => {
            return {
                addChart: (type, data, options) => {
                    const objectName = this.generateObjectName(generateElement, addedObjects);
                    pgenSlide.addChart(type, data, this.getOptions(options, objectName));
                },
                addImage: (options) => {
                    const objectName = this.generateObjectName(generateElement, addedObjects);
                    pgenSlide.addImage(this.getOptions(options, objectName));
                },
                addShape: (shapeName, options) => {
                    const objectName = this.generateObjectName(generateElement, addedObjects);
                    pgenSlide.addShape(shapeName, this.getOptions(options, objectName));
                },
                addTable: (tableRows, options) => {
                    const objectName = this.generateObjectName(generateElement, addedObjects);
                    pgenSlide.addTable(tableRows, this.getOptions(options, objectName));
                },
                addText: (text, options) => {
                    const objectName = this.generateObjectName(generateElement, addedObjects);
                    pgenSlide.addText(text, this.getOptions(options, objectName));
                },
            };
        };
        this.getOptions = (options, objectName) => {
            options = options || {};
            return Object.assign(Object.assign({}, options), { objectName });
        };
        this.automizer = automizer;
        this.slides = slides;
    }
    create() {
        this.generator = new pptxgenjs_1.default();
        return this;
    }
    generateSlides() {
        return __awaiter(this, void 0, void 0, function* () {
            this.tmpFile = (0, crypto_1.randomUUID)() + '.pptx';
            for (const slide of this.slides) {
                const generate = slide.getGeneratedElements();
                if (generate.length) {
                    this.countSlides++;
                    this.addElements(generate, this.appendPptxGenSlide(), slide);
                }
            }
            if (this.countSlides > 0) {
                yield this.generator.writeFile({
                    fileName: this.automizer.templateDir + '/' + this.tmpFile,
                });
                this.automizer.load(this.tmpFile);
            }
        });
    }
    addElements(generate, pgenSlide, slide) {
        generate.forEach((generateElement) => {
            generateElement.tmpSlideNumber = this.countSlides;
            const addedObjects = [];
            generateElement.callback(this.supportedSlideItems(pgenSlide, generateElement, addedObjects), this.generator);
            addedObjects.forEach((addedObjectName) => {
                slide.addElement(this.tmpFile, this.countSlides, addedObjectName);
            });
        });
    }
    generateObjectName(generateElement, addedObjects) {
        const objectName = (generateElement.objectName ? generateElement.objectName + '-' : '') +
            (0, crypto_1.randomUUID)();
        addedObjects.push(objectName);
        return objectName;
    }
    appendPptxGenSlide() {
        return this.generator.addSlide();
    }
    cleanup() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.countSlides > 0) {
                fs_1.default.unlinkSync(this.automizer.templateDir + '/' + this.tmpFile);
            }
        });
    }
}
exports.default = GeneratePptxGenJs;
//# sourceMappingURL=generate-pptxgenjs.js.map